summaryrefslogtreecommitdiffstats
path: root/chromium/chrome/browser/extensions/api/browsing_data/browsing_data_test.cc
diff options
context:
space:
mode:
Diffstat (limited to 'chromium/chrome/browser/extensions/api/browsing_data/browsing_data_test.cc')
-rw-r--r--chromium/chrome/browser/extensions/api/browsing_data/browsing_data_test.cc16
1 files changed, 8 insertions, 8 deletions
diff --git a/chromium/chrome/browser/extensions/api/browsing_data/browsing_data_test.cc b/chromium/chrome/browser/extensions/api/browsing_data/browsing_data_test.cc
index b2e4c22d486..04622a3e005 100644
--- a/chromium/chrome/browser/extensions/api/browsing_data/browsing_data_test.cc
+++ b/chromium/chrome/browser/extensions/api/browsing_data/browsing_data_test.cc
@@ -49,12 +49,13 @@ const char kRemoveEverythingArguments[] =
"webSQL": true
}])";
// Sets the APISID Gaia cookie, which is monitored by the AccountReconcilor.
bool SetGaiaCookieForProfile(Profile* profile) {
- GURL google_url = GaiaUrls::GetInstance()->google_url();
- net::CanonicalCookie cookie("APISID", std::string(), "." + google_url.host(),
+ GURL google_url = GaiaUrls::GetInstance()->secure_google_url();
+ net::CanonicalCookie cookie("SAPISID", std::string(), "." + google_url.host(),
"/", base::Time(), base::Time(), base::Time(),
- false, false, net::CookieSameSite::NO_RESTRICTION,
+ /*secure=*/true, false,
+ net::CookieSameSite::NO_RESTRICTION,
net::COOKIE_PRIORITY_DEFAULT);
bool success = false;
@@ -70,10 +71,8 @@ bool SetGaiaCookieForProfile(Profile* profile) {
network::mojom::CookieManager* cookie_manager =
content::BrowserContext::GetDefaultStoragePartition(profile)
->GetCookieManagerForBrowserProcess();
- net::CookieOptions options;
- options.set_include_httponly();
cookie_manager->SetCanonicalCookie(
- cookie, google_url.scheme(), options,
+ cookie, google_url.scheme(), net::CookieOptions::MakeAllInclusive(),
mojo::WrapCallbackWithDefaultInvokeIfNotRun(
std::move(callback), net::CanonicalCookie::CookieInclusionStatus(
net::CanonicalCookie::CookieInclusionStatus::
@@ -106,7 +105,8 @@ IN_PROC_BROWSER_TEST_F(ExtensionBrowsingDataTest, Syncing) {
syncer::SyncService* sync_service =
ProfileSyncServiceFactory::GetForProfile(profile);
sync_service->GetUserSettings()->SetSyncRequested(true);
- sync_service->GetUserSettings()->SetFirstSetupComplete();
+ sync_service->GetUserSettings()->SetFirstSetupComplete(
+ syncer::SyncFirstSetupCompleteSource::BASIC_FLOW);
ASSERT_EQ(sync_ui_util::SYNCED, sync_ui_util::GetStatus(profile));
// Clear browsing data.
@@ -49,12 +49,13 @@ const char kRemoveEverythingArguments[] =
"webSQL": true
}])";
-// Sets the APISID Gaia cookie, which is monitored by the AccountReconcilor.
+// Sets the SAPISID Gaia cookie, which is monitored by the AccountReconcilor.
bool SetGaiaCookieForProfile(Profile* profile) {